@@ -21,6 +21,10 @@
  *          Mike Hearn  <mike@theoretic.com>
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "sound-juicer.h"
 
 #include <string.h>
@@ -33,11 +37,12 @@
 #include <gconf/gconf-client.h>
 #include <brasero-medium-selection.h>
 #include <brasero-volume.h>
-#include <libgnome-media-profiles/gnome-media-profiles.h>
 #include <gst/gst.h>
+#include <gst/pbutils/encoding-profile.h>
 
 #include "bacon-message-connection.h"
 #include "gconf-bridge.h"
+#include "rb-gst-media-types.h"
 #include "sj-about.h"
 #include "sj-metadata-getter.h"
 #include "sj-extractor.h"
@@ -410,9 +415,11 @@ musicbrainz_submit_info_bar_new (char *title, char *artist)
   g_return_val_if_fail (title != NULL, NULL);
   g_return_val_if_fail (artist != NULL, NULL);
 
-  infobar = gtk_info_bar_new_with_buttons (_("S_ubmit Album"), GTK_RESPONSE_OK,
-                                           GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                           NULL);
+  infobar = gtk_info_bar_new ();
+  button = gtk_info_bar_add_button (GTK_INFO_BAR (infobar),
+                                    _("S_ubmit Album"), GTK_RESPONSE_OK);
+  gtk_info_bar_add_button (GTK_INFO_BAR (infobar),
+                           GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
   /* Translators: title, artist */
   primary_text = g_strdup_printf (_("Could not find %s by %s on MusicBrainz."), title, artist);
@@ -487,10 +494,14 @@ static void update_ui_for_album (AlbumDetails *album)
     gtk_entry_set_text (GTK_ENTRY (title_entry), album->title);
     gtk_entry_set_text (GTK_ENTRY (artist_entry), album->artist);
     if (album->disc_number) {
-      gtk_entry_set_text (GTK_ENTRY (disc_number_entry), g_strdup_printf ("%d", album->disc_number));
+      gchar *disc_number = g_strdup_printf ("%d", album->disc_number);
+      gtk_entry_set_text (GTK_ENTRY (disc_number_entry), disc_number);
+      g_free (disc_number);
     }
     if (album->release_date && g_date_valid (album->release_date)) {
-      gtk_entry_set_text (GTK_ENTRY (year_entry), g_strdup_printf ("%d", g_date_get_year (album->release_date)));
+      gchar *release_date =  g_strdup_printf ("%d", g_date_get_year (album->release_date));
+      gtk_entry_set_text (GTK_ENTRY (year_entry), release_date);
+      g_free (release_date);
     }
     g_signal_handlers_unblock_by_func (title_entry, on_title_edit_changed, NULL);
     g_signal_handlers_unblock_by_func (artist_entry, on_artist_edit_changed, NULL);
@@ -691,11 +702,15 @@ static void baseuri_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *
 static void path_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
   g_assert (strcmp (entry->key, GCONF_PATH_PATTERN) == 0);
+
+  if (path_pattern)
+    g_free (path_pattern);
+
   if (entry->value == NULL) {
     /* TODO: this value and the value in sj-prefs need to be in one place */
     path_pattern = g_strdup ("%aa/%at");
   } else {
-    path_pattern = gconf_value_get_string (entry->value);
+    path_pattern = g_strdup (gconf_value_get_string (entry->value));
   }
   /* TODO: sanity check the pattern */
 }
@@ -706,11 +721,15 @@ static void path_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
 static void file_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
   g_assert (strcmp (entry->key, GCONF_FILE_PATTERN) == 0);
+
+  if (file_pattern)
+    g_free (file_pattern);
+
   if (entry->value == NULL) {
     /* TODO: this value and the value in sj-prefs need to be in one place */
     file_pattern = g_strdup ("%tN-%tt");
   } else {
-    file_pattern = gconf_value_get_string (entry->value);
+    file_pattern = g_strdup (gconf_value_get_string (entry->value));
   }
   /* TODO: sanity check the pattern */
 }
@@ -812,6 +831,7 @@ metadata_cb (SjMetadataGetter *m, GList *albums, GError *error)
     return;
   }
 
+  g_free (current_submit_url);
   current_submit_url = sj_metadata_getter_get_submit_url (metadata);
   if (current_submit_url) {
     gtk_widget_set_sensitive (submit_menuitem, TRUE);
@@ -886,10 +906,10 @@ static void reread_cd (gboolean ignore_no_media)
 
   /* Set watch cursor */
   if (realized) {
-    cursor = gdk_cursor_new_for_display (gtk_widget_get_display (GTK_WIDGET (window)), GDK_WATCH);
+    cursor = gdk_cursor_new_for_display (gtk_widget_get_display (GTK_WIDGET (main_window)), GDK_WATCH);
     gdk_window_set_cursor (window, cursor);
     gdk_cursor_unref (cursor);
-    gdk_display_sync (gtk_widget_get_display (GTK_WIDGET (window)));
+    gdk_display_sync (gtk_widget_get_display (GTK_WIDGET (main_window)));
   }
 
   /* Set statusbar message */
@@ -1126,11 +1146,13 @@ static void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *e
 
 static void profile_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
-  GMAudioProfile *profile;
+  GstEncodingProfile *profile;
+  const char *media_type;
 
-  g_assert (strcmp (entry->key, GCONF_AUDIO_PROFILE) == 0);
+  g_assert (strcmp (entry->key, GCONF_AUDIO_PROFILE_MEDIA_TYPE) == 0);
   if (!entry->value) return;
-  profile = gm_audio_profile_lookup (gconf_value_get_string (entry->value));
+  media_type = gconf_value_get_string (entry->value);
+  profile = rb_gst_get_encoding_profile (media_type);
   if (profile != NULL)
     g_object_set (extractor, "profile", profile, NULL);
 
@@ -1154,6 +1176,9 @@ static void profile_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *
       exit(0);
     }
   }
+
+  if (profile != NULL)
+    gst_encoding_profile_unref (profile);
 }
 
 /**
@@ -1678,7 +1703,7 @@ int main (int argc, char **argv)
   gconf_client_notify_add (gconf_client, GCONF_OPEN, open_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_BASEURI, baseuri_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_STRIP, strip_changed_cb, NULL, NULL, NULL);
-  gconf_client_notify_add (gconf_client, GCONF_AUDIO_PROFILE, profile_changed_cb, NULL, NULL, NULL);
+  gconf_client_notify_add (gconf_client, GCONF_AUDIO_PROFILE_MEDIA_TYPE, profile_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_PARANOIA, paranoia_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_PATH_PATTERN, path_pattern_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_FILE_PATTERN, file_pattern_changed_cb, NULL, NULL, NULL);
@@ -1688,9 +1713,6 @@ int main (int argc, char **argv)
   gconf_client_notify_add (gconf_client, GCONF_HTTP_PROXY, http_proxy_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_HTTP_PROXY_PORT, http_proxy_port_changed_cb, NULL, NULL, NULL);
 
-  /* init gnome-media-profiles */
-  gnome_media_profiles_init (gconf_client);
-
   builder = gtk_builder_new ();
   if (g_file_test (SOURCE_BUILDER, G_FILE_TEST_EXISTS) != FALSE) {
     gtk_builder_add_from_file (builder, SOURCE_BUILDER, &error);
@@ -1747,6 +1769,7 @@ int main (int argc, char **argv)
                               fake_button2);
 
     gtk_size_group_add_widget (size_group, play_button);
+    g_object_unref (G_OBJECT (size_group));
   }
 
   setup_genre_entry (genre_entry);
@@ -1824,36 +1847,80 @@ int main (int argc, char **argv)
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (track_listview));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
-  http_proxy_setup (gconf_client);
-  baseuri_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_BASEURI, NULL, TRUE, NULL), NULL);
-  path_pattern_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_PATH_PATTERN, NULL, TRUE, NULL), NULL);
-  file_pattern_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_FILE_PATTERN, NULL, TRUE, NULL), NULL);
-  profile_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_AUDIO_PROFILE, NULL, TRUE, NULL), NULL);
-  paranoia_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_PARANOIA, NULL, TRUE, NULL), NULL);
-  strip_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_STRIP, NULL, TRUE, NULL), NULL);
-  eject_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_EJECT, NULL, TRUE, NULL), NULL);
-  open_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_OPEN, NULL, TRUE, NULL), NULL);
-  audio_volume_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_AUDIO_VOLUME, NULL, TRUE, NULL), NULL);
-  if (device == NULL && uris == NULL) {
-    device_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_DEVICE, NULL, TRUE, NULL), GINT_TO_POINTER (TRUE));
-  } else {
-    if (device)
-      set_device (device, TRUE);
-    else {
-      char *d;
+  {
+    GConfEntry *entry;
+    http_proxy_setup (gconf_client);
 
-      /* Mash up the CDDA URIs into a device path */
-      if (g_str_has_prefix (uris[0], "cdda://")) {
-      	gint len;
-        d = g_strdup_printf ("/dev/%s%c", uris[0] + strlen ("cdda://"), '\0');
-        /* Take last '/' out of path, or set_device thinks it is part of the device name */
-		len = strlen (d);
-		if (d[len - 1] == '/')
-			d [len - 1] = '\0';
-	set_device (d, TRUE);
-	g_free (d);
+    entry = gconf_client_get_entry (gconf_client, GCONF_BASEURI, NULL, TRUE, NULL);
+    baseuri_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    entry = gconf_client_get_entry (gconf_client, GCONF_PATH_PATTERN, NULL, TRUE, NULL);
+    path_pattern_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    entry = gconf_client_get_entry (gconf_client, GCONF_FILE_PATTERN, NULL, TRUE, NULL);
+    file_pattern_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    entry = gconf_client_get_entry (gconf_client, GCONF_AUDIO_PROFILE_MEDIA_TYPE, NULL, TRUE, NULL);
+    profile_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    entry = gconf_client_get_entry (gconf_client, GCONF_PARANOIA, NULL, TRUE, NULL);
+    paranoia_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    entry = gconf_client_get_entry (gconf_client, GCONF_STRIP, NULL, TRUE, NULL);
+    strip_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    entry = gconf_client_get_entry (gconf_client, GCONF_EJECT, NULL, TRUE, NULL);
+    eject_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    entry = gconf_client_get_entry (gconf_client, GCONF_OPEN, NULL, TRUE, NULL);
+    open_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    entry = gconf_client_get_entry (gconf_client, GCONF_AUDIO_VOLUME, NULL, TRUE, NULL);
+    audio_volume_changed_cb (gconf_client, -1, entry, NULL);
+    gconf_entry_unref (entry);
+
+    if (device == NULL && uris == NULL) {
+      entry = gconf_client_get_entry (gconf_client, GCONF_DEVICE, NULL, TRUE, NULL);
+      device_changed_cb (gconf_client, -1, entry, GINT_TO_POINTER (TRUE));
+      gconf_entry_unref (entry);
+    } else {
+      if (device) {
+#ifdef __sun
+        if (strstr(device, "/dev/dsk/") != NULL ) {
+          device = g_strdup_printf("/dev/rdsk/%s", device + strlen("/dev/dsk/"));
+        }
+#endif
+        set_device (device, TRUE);
       } else {
-        device_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_DEVICE, NULL, TRUE, NULL), GINT_TO_POINTER (TRUE));
+        char *d;
+
+        /* Mash up the CDDA URIs into a device path */
+        if (g_str_has_prefix (uris[0], "cdda://")) {
+          gint len;
+#ifdef __sun
+          d = g_strdup_printf ("/dev/rdsk/%s", uris[0] + strlen ("cdda://"));
+#else
+          d = g_strdup_printf ("/dev/%s%c", uris[0] + strlen ("cdda://"), '\0');
+#endif
+          /* Take last '/' out of path, or set_device thinks it is part of the device name */
+          len = strlen (d);
+          if (d[len - 1] == '/')
+              d [len - 1] = '\0';
+          set_device (d, TRUE);
+          g_free (d);
+        } else {
+          entry = gconf_client_get_entry (gconf_client, GCONF_DEVICE, NULL, TRUE, NULL);
+          device_changed_cb (gconf_client, -1, entry, GINT_TO_POINTER (TRUE));
+          gconf_entry_unref (entry);
+        }
       }
     }
   }
